pub trait ToConstraintField<F: Field> {
// Required method
fn to_field_elements(&self) -> Option<Vec<F>>;
}Expand description
Types that can be converted to a vector of F elements. Useful for
specifying how public inputs to a constraint system should be represented
inside that constraint system.
Required Methods
fn to_field_elements(&self) -> Option<Vec<F>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".